@@ -33,6 +33,7 @@ import pytest
 from pytest import FixtureRequest  # noqa: PT013
 
 from molecule.command import base
+from molecule.util import safe_load
 from tests.conftest import mac_on_gh  # pylint:disable=C0411
 
 
@@ -102,7 +103,7 @@ def has_pure_docker() -> bool:
     else:
         result = run(["docker", "context", "inspect", "--format", "{{.Endpoints.docker.Host}}"])
         if result.returncode != 0:
-            failure = "Docker was not able to report its currently active socket for current context: {result}"
+            failure = f"Docker was not able to report its currently active socket for current context: {result.stderr.rstrip()}"
         else:
             docker_current_socket = result.stdout.rstrip()
             warnings.warn(
@@ -499,3 +500,68 @@ def test_smoke(monkeypatch: pytest.MonkeyPatch, test_fixture_dir: Path, app: App
     command = ["molecule", "test", "--scenario-name", "smoke"]
     result = run(command)
     assert result.returncode == 0, result
+
+
+def test_with_backend_as_ansible_playbook(
+    monkeypatch: pytest.MonkeyPatch,
+    test_fixture_dir: Path,
+) -> None:
+    """Execute test-scenario (smoke test) that should spot potentially breaking changes.
+
+    Args:
+        monkeypatch: Pytest fixture.
+        test_fixture_dir: Path to the test fixture directory.
+    """
+    monkeypatch.chdir(test_fixture_dir)
+    command = ["molecule", "test", "--scenario-name", "test-scenario"]
+    result = run(command)
+    assert result.returncode == 0, result
+
+
+@mac_on_gh
+def test_with_backend_as_ansible_navigator(
+    monkeypatch: pytest.MonkeyPatch,
+    test_fixture_dir: Path,
+) -> None:
+    """Execute test-scenario-for-nav (smoke test) that should spot potentially breaking changes.
+
+    Args:
+        monkeypatch: Pytest fixture.
+        test_fixture_dir: Path to the test fixture directory.
+    """
+    monkeypatch.chdir(test_fixture_dir)
+    command = ["molecule", "test", "--scenario-name", "test-scenario-for-nav"]
+    result = run(command)
+    assert result.returncode == 0, result
+
+
+def test_shared_actions(
+    monkeypatch: pytest.MonkeyPatch,
+    test_fixture_dir: Path,
+) -> None:
+    """Test that shared-state properly threads scenarios.
+
+    Args:
+        monkeypatch: Pytest fixture.
+        test_fixture_dir: Path to the test fixture directory.
+    """
+    monkeypatch.chdir(test_fixture_dir)
+    cmd = [
+        "molecule",
+        "test",
+        "--shared-state",
+        "-s",
+        "test-scenario",
+        "-s",
+        "smoke",
+        "--report",
+    ]
+    result = run(cmd=cmd)
+    assert result.returncode == 0, result
+    out = result.stdout
+    # If we redesign --report, this needs to be updated
+    run_report = safe_load(out[out.rindex("---") :])
+    assert run_report[0]["name"] == "default"
+    assert run_report[1]["name"] == "test-scenario"
+    assert run_report[2]["name"] == "smoke"
+    assert run_report[3]["name"] == "default"
