@@ -22,6 +22,7 @@ from __future__ import annotations
 import collections
 import os
 
+from pathlib import Path
 from typing import TYPE_CHECKING, Any
 
 import pytest
@@ -37,6 +38,8 @@ if TYPE_CHECKING:
 
     from pytest_mock import MockerFixture
 
+    from molecule.provisioner.ansible import Ansible
+
 
 @pytest.fixture
 def _patched_ansible_playbook(mocker: MockerFixture) -> MagicMock:
@@ -260,9 +263,38 @@ def test_links_property(instance):  # type: ignore[no-untyped-def]  # noqa: ANN2
     assert instance.links == {}
 
 
-def test_inventory_directory_property(instance):  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
-    x = os.path.join(instance._config.scenario.ephemeral_directory, "inventory")  # noqa: PTH118
-    assert x == instance.inventory_directory
+def test_inventory_directory_property(instance: Ansible) -> None:
+    """Test the inventory_directory property.
+
+    Args:
+        instance: Ansible provisioner instance.
+    """
+    x = Path(instance._config.scenario.ephemeral_directory, "inventory")
+    assert str(x) == instance.inventory_directory
+
+
+def test_inventory_directory_property_shared(instance: Ansible) -> None:
+    """Test the shared_inventory_directory property.
+
+    Args:
+        instance: Ansible provisioner instance.
+    """
+    instance._config.command_args["shared_inventory"] = True
+    x = Path(instance._config.scenario.shared_ephemeral_directory, "inventory")
+    assert str(x) == instance.inventory_directory
+
+
+def test_inventory_directory_property_shared_parallel(instance: Ansible) -> None:
+    """Test the shared_inventory_directory property with parallel mode on.
+
+    Args:
+        instance: Ansible provisioner instance.
+    """
+    instance._config.command_args["shared_inventory"] = True
+    instance._config.command_args["parallel"] = True
+    # Parallel disables shared ephemeral directory
+    x = Path(instance._config.scenario.ephemeral_directory, "inventory")
+    assert str(x) == instance.inventory_directory
 
 
 def test_inventory_file_property(instance):  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
